@@ -13,9 +13,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Written by:
  *     Jasper St. Pierre <jstpierre@mecheye.net>
@@ -37,7 +35,9 @@ struct _GisPagePrivate
   gpointer apply_data;
 
   guint complete : 1;
-  guint padding : 6;
+  guint skippable : 1;
+  guint needs_accept : 1;
+  guint padding : 5;
 };
 typedef struct _GisPagePrivate GisPagePrivate;
 
@@ -49,6 +49,8 @@ enum
   PROP_DRIVER,
   PROP_TITLE,
   PROP_COMPLETE,
+  PROP_SKIPPABLE,
+  PROP_NEEDS_ACCEPT,
   PROP_APPLYING,
   PROP_LAST,
 };
@@ -74,6 +76,12 @@ gis_page_get_property (GObject    *object,
     case PROP_COMPLETE:
       g_value_set_boolean (value, priv->complete);
       break;
+    case PROP_SKIPPABLE:
+      g_value_set_boolean (value, priv->skippable);
+      break;
+    case PROP_NEEDS_ACCEPT:
+      g_value_set_boolean (value, priv->needs_accept);
+      break;
     case PROP_APPLYING:
       g_value_set_boolean (value, gis_page_get_applying (page));
       break;
@@ -99,6 +107,12 @@ gis_page_set_property (GObject      *object,
     case PROP_TITLE:
       gis_page_set_title (page, (char *) g_value_get_string (value));
       break;
+    case PROP_SKIPPABLE:
+      priv->skippable = g_value_get_boolean (value);
+      break;
+    case PROP_NEEDS_ACCEPT:
+      priv->needs_accept = g_value_get_boolean (value);
+      break;
     case PROP_COMPLETE:
       priv->complete = g_value_get_boolean (value);
       break;
@@ -132,51 +146,14 @@ gis_page_dispose (GObject *object)
     g_cancellable_cancel (priv->apply_cancel);
 
   g_clear_object (&page->driver);
-  g_clear_object (&page->builder);
 
   G_OBJECT_CLASS (gis_page_parent_class)->dispose (object);
 }
 
-static GtkBuilder *
-gis_page_real_get_builder (GisPage *page)
-{
-  GisPageClass *klass = GIS_PAGE_GET_CLASS (page);
-  GtkBuilder *builder;
-  gchar *resource_path;
-  GError *error = NULL;
-
-  if (klass->page_id == NULL)
-    {
-      g_warning ("Null page ID. Won't construct builder.");
-      return NULL;
-    }
-
-  resource_path = g_strdup_printf ("/org/gnome/initial-setup/gis-%s-page.ui", klass->page_id);
-
-  builder = gtk_builder_new ();
-  gtk_builder_add_from_resource (builder, resource_path, &error);
-
-  if (error != NULL) {
-    g_warning ("Error while loading %s: %s", resource_path, error->message);
-    g_free (resource_path);
-    g_error_free (error);
-    goto err;
-  }
-
-  g_free (resource_path);
-  return builder;
- err:
-  g_object_unref (builder);
-  return NULL;
-}
-
 static void
 gis_page_constructed (GObject *object)
 {
   GisPage *page = GIS_PAGE (object);
-  GisPageClass *klass = GIS_PAGE_GET_CLASS (page);
-
-  page->builder = klass->get_builder (page);
 
   gis_page_locale_changed (page);
 
@@ -201,7 +178,6 @@ gis_page_class_init (GisPageClass *klass)
   object_class->get_property = gis_page_get_property;
   object_class->set_property = gis_page_set_property;
 
-  klass->get_builder = gis_page_real_get_builder;
   klass->apply = gis_page_real_apply;
 
   obj_props[PROP_DRIVER] =
@@ -213,6 +189,12 @@ gis_page_class_init (GisPageClass *klass)
   obj_props[PROP_COMPLETE] =
     g_param_spec_boolean ("complete", "", "", FALSE,
                           G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+  obj_props[PROP_SKIPPABLE] =
+    g_param_spec_boolean ("skippable", "", "", FALSE,
+                          G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+  obj_props[PROP_NEEDS_ACCEPT] =
+    g_param_spec_boolean ("needs-accept", "", "", FALSE,
+                          G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
   obj_props[PROP_APPLYING] =
     g_param_spec_boolean ("applying", "", "", FALSE,
                           G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
@@ -223,6 +205,10 @@ gis_page_class_init (GisPageClass *klass)
 static void
 gis_page_init (GisPage *page)
 {
+  gtk_widget_set_margin_start (GTK_WIDGET (page), 12);
+  gtk_widget_set_margin_top (GTK_WIDGET (page), 12);
+  gtk_widget_set_margin_bottom (GTK_WIDGET (page), 12);
+  gtk_widget_set_margin_end (GTK_WIDGET (page), 12);
 }
 
 char *
@@ -259,6 +245,36 @@ gis_page_set_complete (GisPage *page, gboolean complete)
   g_object_notify_by_pspec (G_OBJECT (page), obj_props[PROP_COMPLETE]);
 }
 
+gboolean
+gis_page_get_skippable (GisPage *page)
+{
+  GisPagePrivate *priv = gis_page_get_instance_private (page);
+  return priv->skippable;
+}
+
+void
+gis_page_set_skippable (GisPage *page, gboolean skippable)
+{
+  GisPagePrivate *priv = gis_page_get_instance_private (page);
+  priv->skippable = skippable;
+  g_object_notify_by_pspec (G_OBJECT (page), obj_props[PROP_SKIPPABLE]);
+}
+
+gboolean
+gis_page_get_needs_accept (GisPage *page)
+{
+  GisPagePrivate *priv = gis_page_get_instance_private (page);
+  return priv->needs_accept;
+}
+
+void
+gis_page_set_needs_accept (GisPage *page, gboolean needs_accept)
+{
+  GisPagePrivate *priv = gis_page_get_instance_private (page);
+  priv->needs_accept = needs_accept;
+  g_object_notify_by_pspec (G_OBJECT (page), obj_props[PROP_NEEDS_ACCEPT]);
+}
+
 void
 gis_page_locale_changed (GisPage *page)
 {
@@ -279,9 +295,6 @@ gis_page_apply_begin (GisPage                *page,
 
   klass = GIS_PAGE_GET_CLASS (page);
 
-  /* Unrefs in gis_page_apply_complete() */
-  g_object_ref (page);
-
   priv->apply_cb = callback;
   priv->apply_data = user_data;
   priv->apply_cancel = g_cancellable_new ();
@@ -318,9 +331,6 @@ gis_page_apply_complete (GisPage *page,
 
   if (callback)
     (callback) (page, valid, user_data);
-
-  /* Matches ref in gis_page_apply_begin() */
-  g_object_unref (page);
 }
 
 gboolean
